# sky130 gdsfactory PDK 0.0.10

[![pypi](https://img.shields.io/pypi/v/sky130)](https://pypi.org/project/sky130/)
[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

gdsfactory pdk based on [skywater130](https://github.com/google/skywater-pdk)

![](https://i.imgur.com/xvnfEtZ.png)

## Installation

For users:

```
pip install sky130
```

For developers:

```
git clone https://github.com/gdsfactory/skywater130.git
cd skywater130
make install
```

## TODO

- integrate with OpenRoad
- define port orientation
- add some sample netlist
